package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````8"````````!``````````'"Q````
M`````````$``.``)`$``'``;``8````%````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````,B=````````R)T`````````
M`"````````$````&````D*L```````"0JR```````)"K(```````D`0`````
M```8%0``````````(````````@````8```"XJP```````+BK(```````N*L@
M```````0`@```````!`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````X)8```````#@E@```````."6````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````)"K````````D*L@``````"0JR``
M`````'`$````````<`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````,````"``````````0`
M```4`````P```$=.50"()'QFIR-XJ@LY6&AT<!QZ+D/7"A$```!$````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA-N@0&"@````!$````
M2````$P```!-````5````%4```!7````6P```%P`````````7@```&$```!B
M````8P``````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\#RV],=NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QFQ;F<
M0$)%U>S$B060B`=PTSGRBQP-%.*>VLWCGC-BV^T,.I<+5J2;EJ?=HVM_J9R;
MX:<""@J*$%>CX/M)````````````````````````````````$0$``!(`````
M````````````````````YP$``!(`````````````````````````70(``!(`
M````````````````````````.P(``!(`````````````````````````$0``
M`"``````````````````````````9`(``!(`````````````````````````
M\`(``!(`````````````````````````M````!(`````````````````````
M````>0(``!(`````````````````````````@P$``!(`````````````````
M````````V`(``!(`````````````````````````T`(``!(`````````````
M````````````A````!(`````````````````````````L0,``!(`````````
M````````````````#`$``!(`````````````````````````G`(``!(`````
M````````````````````C@(``!(`````````````````````````3`(``!(`
M````````````````````````Z0(``!(`````````````````````````!@,`
M`!(`````````````````````````9P$``!(`````````````````````````
M-0$``!(`````````````````````````P@```!(`````````````````````
M````L0$``!(`````````````````````````%`(``!(`````````````````
M````````0P(``!(`````````````````````````)`(``!(`````````````
M````````````G@$``!(`````````````````````````<@(``!(`````````
M````````````````X@$``!(`````````````````````````2@,``!(`````
M````````````````````0P,``!(`````````````````````````0P$``!(`
M````````````````````````^0(``!(`````````````````````````+0``
M`"``````````````````````````L`(``!(`````````````````````````
M9````!(```````````````````````````(``!(`````````````````````
M````J@$``!(`````````````````````````DP```!(`````````````````
M````````GP```!(`````````````````````````7`$``!(`````````````
M````````````(@$``!(`````````````````````````5@```!(`````````
M````````````````%@$``!(`````````````````````````MP(``!(`````
M````````````````````DP$``!(`````````````````````````\````!(`
M````````````````````````:@(``!(`````````````````````````VP$`
M`!(`````````````````````````-`,``!(`````````````````````````
M#0,``!(`````````````````````````=0$``!(`````````````````````
M````<P```!(`````````````````````````/`,``!(`````````````````
M````````AP(``!(`````````````````````````U````!(`````````````
M````````````4P$``!(`````````````````````````Q0(``!(`````````
M````````````````-@(``!(`````````````````````````^`$``!(`````
M````````````````````H@(``!(`````````````````````````/````"``
M````````````````````````@`(``!(`````````````````````````%P,`
M`"(`````````````````````````E0(``!(`````````````````````````
M)@,``!(`````````````````````````N@,``!(`#@"`5@```````'``````
M````B`,``!(`#P"$5P``````````````````WP,``!(`#@`P1@```````%0,
M````````5P,``!(`#@`P'@```````"T"````````C@,``!(`#@!P/P``````
M``4`````````300``!(`#@"`/P```````!H"````````1P0``!(`"P!`&@``
M````````````````>@0``!(`#@"04@```````.T#````````;0,``!``&0`@
ML"``````````````````Q@,``!(`#@"@00```````"H`````````^0,``!$`
M$`"05P````````0`````````O`$``!$`%0"@JR```````!,`````````>0,`
M`!``&0"HP"``````````````````100``!(`#@`@/@```````#``````````
M6@0``!(`#@!010```````-P`````````;`0``!(`#@"@1````````'0`````
M````[`,``!``&```L"``````````````````TP,``!(`#@#000```````.P`
M````````7`,``!$`&0!(L"````````@`````````9@,``!``&``@L"``````
M````````````70,``"$`&0!(L"````````@`````````+@0``!$`&``8L"``
M``````@`````````X@(``!$`&0!@L"````````@`````````?@,``!(`#@"`
M5P````````(`````````'@0``!(`#@`05P```````&4`````````\@,``!(`
M#@!@(````````"L`````````[@,``"``&```L"```````````````````0$`
M`!$`&0`@L"````````0`````````7@,``"$`&0!(L"````````@`````````
MGP,``!(`#@`@10```````"0`````````"`0``!(`#@"@/@```````,$`````
M````XP```!$`&0!`L"````````$`````````.`0``!(`#@#`0@```````-L!
M`````````&QI8G!E<FPN<V\N-2XR-@!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V
M7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?
M:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`
M4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!R96%D`%]?
M97)R;F]?;&]C871I;VX`;'-E96LV-`!P=&AR96%D7V=E='-P96-I9FEC`&-L
M;W-E`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``
M8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO
M8P!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`'-T<G-T<@!R
M;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS
M=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN
M:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ
M90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`
M7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE
M7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D
M:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S
M960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P
M87)?<&P`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S
M971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"
M3T]4`$=,24)#7S(N,BXU`$=,24)#7S(N,30`1TQ)0D-?,BXS+C0`1TQ)0D-?
M,BXS+C(`1TQ)0D-?,BXT``````(``P`"``(````"``(````"`````@`"````
M`@````(``@`$``(``@````````````,``@`%`````@`#``(``@````8````'
M`````P`"``````````````````8```````(``P`"``(```````(``@``````
M`@`"``,`!@````(``@`"``8``0`!``$``0`!``$``0`!``$``0`!`````0`!
M``$``0`!``$``@`!``(``0`"``$``0`!``$````"``$``0````$```````$`
M`0#+`0``$````"````!U&FD)```#`)`$`````````0`%`!H"```0````````
M`)21E@8```<`G`0``!````!T&6D)```&`*<$```0````<AEI"0``!0"S!```
M$````!1I:0T```0`OP0``!````!U&FD)```"`)`$````````D*L@```````(
M`````````&`A````````F*L@```````(`````````"`A````````"+`@````
M```(``````````BP(```````&+`@```````(`````````*A:````````N*\@
M```````&````!0``````````````P*\@```````&````"@``````````````
MR*\@```````&````'P``````````````T*\@```````&````(P``````````
M````V*\@```````&````*P``````````````X*\@```````&````-@``````
M````````Z*\@```````&````/P``````````````\*\@```````&````00``
M````````````H*L@```````%````3P``````````````(+`@```````%````
M7P``````````````0+`@```````%````8P``````````````2+`@```````%
M````5@``````````````8+`@```````%````6@``````````````X*T@````
M```'`````0``````````````Z*T@```````'`````@``````````````\*T@
M```````'`````P``````````````^*T@```````'````!```````````````
M`*X@```````'````!@``````````````"*X@```````'````!P``````````
M````$*X@```````'````"```````````````&*X@```````'````"0``````
M````````(*X@```````'````"P``````````````**X@```````'````#```
M````````````,*X@```````'````#0``````````````.*X@```````'````
M#@``````````````0*X@```````'````#P``````````````2*X@```````'
M````$```````````````4*X@```````'````$0``````````````6*X@````
M```'````$@``````````````8*X@```````'````$P``````````````:*X@
M```````'````%```````````````<*X@```````'````%0``````````````
M>*X@```````'````%@``````````````@*X@```````'````%P``````````
M````B*X@```````'````&```````````````D*X@```````'````&0``````
M````````F*X@```````'````&@``````````````H*X@```````'````&P``
M````````````J*X@```````'````'```````````````L*X@```````'````
M'0``````````````N*X@```````'````'@``````````````P*X@```````'
M````(```````````````R*X@```````'````(0``````````````T*X@````
M```'````(@``````````````V*X@```````'````)```````````````X*X@
M```````'````)0``````````````Z*X@```````'````)@``````````````
M\*X@```````'````)P``````````````^*X@```````'````*```````````
M`````*\@```````'````*0``````````````"*\@```````'````*@``````
M````````$*\@```````'````+```````````````&*\@```````'````+0``
M````````````(*\@```````'````+@``````````````**\@```````'````
M+P``````````````,*\@```````'````,```````````````.*\@```````'
M````,0``````````````0*\@```````'````,@``````````````2*\@````
M```'````,P``````````````4*\@```````'````-```````````````6*\@
M```````'````-0``````````````8*\@```````'````-P``````````````
M:*\@```````'````.```````````````<*\@```````'````.0``````````
M````>*\@```````'````.@``````````````@*\@```````'````.P``````
M````````B*\@```````'````/```````````````D*\@```````'````/0``
M````````````F*\@```````'````/@``````````````H*\@```````'````
M0```````````````J*\@```````'````0@``````````````L*\@```````'
M````0P``````````````2(/L"$B+!865(`!(A<!T`O_02(/$",,`````````
M``#_-6J3(`#_)6R3(``/'T``_R5JDR``:`````#IX/____\E8I,@`&@!````
MZ=#_____)5J3(`!H`@```.G`_____R52DR``:`,```#IL/____\E2I,@`&@$
M````Z:#_____)4*3(`!H!0```.F0_____R4ZDR``:`8```#I@/____\E,I,@
M`&@'````Z7#_____)2J3(`!H"````.E@_____R4BDR``:`D```#I4/____\E
M&I,@`&@*````Z4#_____)1*3(`!H"P```.DP_____R4*DR``:`P```#I(/__
M__\E`I,@`&@-````Z1#_____)?J2(`!H#@```.D`_____R7RDB``:`\```#I
M\/[___\EZI(@`&@0````Z>#^____)>*2(`!H$0```.G0_O___R7:DB``:!(`
M``#IP/[___\ETI(@`&@3````Z;#^____)<J2(`!H%````.F@_O___R7"DB``
M:!4```#ID/[___\ENI(@`&@6````Z8#^____);*2(`!H%P```.EP_O___R6J
MDB``:!@```#I8/[___\EHI(@`&@9````Z5#^____)9J2(`!H&@```.E`_O__
M_R62DB``:!L```#I,/[___\EBI(@`&@<````Z2#^____)8*2(`!H'0```.D0
M_O___R5ZDB``:!X```#I`/[___\E<I(@`&@?````Z?#]____)6J2(`!H(```
M`.G@_?___R5BDB``:"$```#IT/W___\E6I(@`&@B````Z<#]____)5*2(`!H
M(P```.FP_?___R5*DB``:"0```#IH/W___\E0I(@`&@E````Z9#]____)3J2
M(`!H)@```.F`_?___R4RDB``:"<```#I</W___\E*I(@`&@H````Z6#]____
M)2*2(`!H*0```.E0_?___R4:DB``:"H```#I0/W___\E$I(@`&@K````Z3#]
M____)0J2(`!H+````.D@_?___R4"DB``:"T```#I$/W___\E^I$@`&@N````
MZ0#]____)?*1(`!H+P```.GP_/___R7JD2``:#````#IX/S___\EXI$@`&@Q
M````Z=#\____)=J1(`!H,@```.G`_/___R72D2``:#,```#IL/S___\ERI$@
M`&@T````Z:#\____)<*1(`!H-0```.F0_/___R6ZD2``:#8```#I@/S___\E
MLI$@`&@W````Z7#\____):J1(`!H.````.E@_/___R6BD2``:#D```#I4/S_
M__\EFI$@`&@Z````Z4#\____)<J1(`!FD```````````55-(@^PXB7PD'$B)
M="002(U\)!Q(B50D"$B-="002(U4)`AD2(L$)2@```!(B40D*#'`Z`C^__](
MBS5ID2``2(L]:I$@`$B)\NAR.```@#V[D2```'4OZ#3]__](A<!(B04*HB``
M#X2W`0``2(G'Z&S\__^+/7:1(`#HT?W__\:`T0@```"+/621(`#HO_W__X"(
MJ@0```*+/5*1(`#HK?W__X"(J@0```&+1"0<C7@%2+C_________'TAC_T@Y
MQP^'(@$``$C!YP-(C1U@.@``Z/G\__](BWPD$$B)!76A(`#'!7.A(``$````
M2(L72(E8"$B-'3HZ``!(B5@82(D02(L5WY`@`$B)4!"+5"0<@_H!1(U*!'XM
M1(U*!$B#QPB^!0```&8/'X0``````$R+!TACSH/&`4B#QPA!.?%,B43(^'7I
M2(L](J$@`$UCR4B--<@>``"#P@-%,<!*QT3(^`````!(B<'H8?W__X7`B<-T
M9$B+/?2@(`!(C6PD).C:^___2(T]=S@``#'`2(GNZ+D7``!(A<!T*DB+/<V@
M(`#H6/O__^CS_/__B=A(BUPD*&1(,QPE*````'5?2(/$.%M=PTB+/9N@(`!(
MA?]T+.AY-@``Z\-(BSV0H"``Z(O]__^)P^N,2(TU@(L@`$B-/;\W```QP.B"
M_/__2(T]M#<``$B)[NA#%P``2(7`2(G'2(D%3J`@`'2`Z[3H#?O__[\!````
MZ&/]__\/'P`Q[4F)T5Y(B>)(@^3P4%1,C04*-P``2(T-DS8``$B-/:S]____
M%3Z/(`#T#Q]$``!(C3V)CR``54B-!8&/(`!(.?A(B>5T&4B+!0J/(`!(A<!T
M#5W_X&8N#Q^$``````!=PP\?0`!F+@\?A```````2(T]28\@`$B--4*/(`!5
M2"G^2(GE2,'^`TB)\$C!Z#](`<9(T?YT&$B+!>F.(`!(A<!T#%W_X&8/'X0`
M`````%W##Q]``&8N#Q^$``````"`/4&/(```=2](@SV_CB```%5(B>5T#$B+
M/<J.(`#HW?S__^A(____Q@49CR```5W##Q^``````//#9@\?1```54B)Y5WI
M9O___V8/'T0``$%7059,C4\X055!5$4QP%532('LF`(``&1(BP0E*````$B)
MA"2(`@``,<!(B>%FD$.+!`%+BS0!#\A(B?*)P$C!ZB!*B01!2(GP2,'N.$C!
MZ"@E`/\``$@)\$B)UDC!X@A(P>88@>(``/\`B?9("?!("=!*B41!"$F#P`A)
M@_A`=:Y(C;$``@``#Q^``````$B+06A(,T%`2(/!"$@S00A(,T'X2(T4`$C!
MZ!]("="#X/](B4%X2#GQ==5,BQ=(BU\02(MW($B+;QA,BT\(3(G03(G22,'J
M&TC!X`5("=`#!"2-E#"9>8):2(G82(MT)`A(,>A,(<A(,>A(C;0UF7F"6D2-
M+`),B<I,B<A(P>@"2,'B'D@)PDB)V$V)Z(G12<'H&T@QR$PAT$@QV$@!\$R)
M[DC!Y@5,"<9$C20&3(G63(G02,'F'DC!Z`)("?!(BW0D$$V)XT@QPDG!ZQM!
MB<!,(>I(C;0SF7F"6D@QRD@!\DR)YDC!Y@5,"=Y$C1P63(GN2(M4)!A)P>T"
M2,'F'DP)[D@Q\$B-E!&9>8):3(G93"'@08GV3#'`2,'I&T@!T$R)VDC!X@5(
M"<I,B>%)P>P"1(TL`DC!X1Y(BU0D($P)X4B)\$@QR$R)[D&)S$PAV$F-E!"9
M>8):2,'N&TPQ\$@!T$R)ZDC!X@5("?)$C00"3(G:2(M$)"A)P>L"2,'B'DP)
MVDR)QD@QT4F-A`:9>8):2,'N&TPAZ4&)TTPQX4@!P4R)P$C!X`5("?!$C30(
M3(GH2(M,)#!)P>T"2,'@'DP)Z$R)]D@QPDF-C`R9>8):08G%3"'"3#':2`'*
M3(GQ2,'A!4C![AM("?%,B<9)P>@"1(TD$4C!YAY(BU0D.$P)QD@Q\$R)X4&)
M\$PA\$F-E!.9>8):2,'I&TPQZ$@!T$R)XDC!X@5("<I,B?%)P>X"1(T<`DC!
MX1Y(BU0D0$P)\4B)\$@QR$R)WD&)SDPAX$F-E!69>8):2,'N&TPQP$@!T$R)
MVDC!X@5("?)$C2P"3(GB2(M$)$A)P>P"2,'B'DP)XDR)[D@QT4F-A`"9>8):
M2,'N&TPAV4&)U$PQ\4@!P4R)Z$C!X`5("?!$C00(3(G82(M,)%!)P>L"2,'@
M'DP)V$R)QD@QPDF-C`Z9>8):2,'N&TPAZD&)PTPQXD@!RDR)P4C!X05("?%,
MB>Y)P>T"1(TT$4C!YAY(BU0D6$P)[D@Q\$R)\4&)]4PAP$F-E!29>8):2,'I
M&TPQV$@!T$R)\DC!X@5("<I,B<%)P>@"1(TD`DC!X1Y(BU0D8$P)P4B)\$@Q
MR$R)YD&)R$F-E!.9>8):3"'P2,'N&TPQZ$@!T$R)XDC!X@5("?)$C1P"3(GR
M2(M$)&A(P>(>2<'N`DP)\DR)WD@QT4F-A`69>8):2,'N&TPAX4&)UDPQP4@!
MP4R)V$C!X`5("?!$C2P(3(G@2(M,)'!)P>P"2,'@'DP)X$R)[D@QPDF-C`B9
M>8):2,'N&TPAVD&)Q$PQ\D@!RDR)Z4C!X05("?%,B=Y)P>L"1(T$$4C!YAY(
MBU0D>$P)WD@Q\$R)P4&)\TPAZ$F-E!:9>8):2,'I&TPQX$@!T$R)PDC!X@5(
M"<I,B>E)P>T"1(TT`DC!X1Y(BY0D@````$P)Z4B)\$@QR$R)]D&)S4PAP$F-
ME!29>8):2,'N&TPQV$@!T$R)\DC!X@5("?)$C20"3(G"2(N$)(@```!)P>@"
M2,'B'DP)PDR)YD@QT4F-A`.9>8):2,'N&TPA\4&)T$PQZ4@!P4R)X$C!X`5(
M"?!(B[0DD````$2-'`A,B?!)P>X"2,'@'DP)\$F-M#69>8):38G=2#'"2<'M
M&XG!3"'B3#'"2`'R3(G>2,'F!4P)[HGV2`'R3(GF2<'L`DC!YAY!B=5,">9,
MBZ0DF````$@Q\$PAV$^-A""9>8):2#'(38GL2<'L&TP!P$V)Z$G!X`5-">!%
MB<!,`<!-B=A)P>L"2<'@'D&)Q$T)V$F)\XGV33'#2`.T)*@```!$,=I,BYPD
MH````$J-C!FAZ]EN38GC2<'K&T@!T4R)XDC!X@5,"=J)TD@!T4R)ZDG![0)(
MP>(>08G+3`GJ38G%18G`23'53`.$)+````!$,>A-B=U(C;0&H>O9;DR)V$G!
M[1M(P>`%3`GHB<!(`?!,B>9)P>P"2,'F'D&)Q4P)YDF)U(G223'T1#'A38GL
M2`.4)+@```!-C80(H>O9;DR)Z4G![!M(P>$%3`GAB<E)`<A,B=E)P>L"2,'A
M'D6)Q$P)V4F)\XGV23'+2`.T),````!$,=A-B>-(C90"H>O9;DR)X$G!ZQM(
MP>`%3`G8B<!(`<),B>A)P>T"2,'@'D&)TTP)Z$F)S8G)23'%2`.,),@```!%
M,>A-B=U.C80&H>O9;DR)WDG![1M(P>8%3`GNB?9,`<9-B>!)P>P"2<'@'D&)
M]4T)X$F)Q(G`33'$1#'B38GL2(V,$:'KV6Y,B>I(P>(%2<'L&T@#A"30````
M3`GBB=)(`=%,B=I)P>L"2,'B'D&)S$P)VDV)PT6)P$DQTTP#A"38````1#'>
M38GC2(VT,*'KV6Y,B>!)P>L;2,'@!4P)V(G`2`'P3(GN2<'M`DC!YAY!B<-,
M">Y)B=6)TDDQ]4@#E"3@````1#'I38G=38V$"*'KV6Y,B=E)P>T;2,'A!4P)
MZ8G)20'(3(GA2<'L`DC!X1Y%B<5,">%)B?2)]DDQS$0QX$V)[$B-E`*AZ]EN
M3(GH2<'L&TC!X`5,">")P$@!PDR)V$@#M"3H````2<'K`DC!X!Y!B=1,"=A)
MB<N)R4DQPT@#C"3P````13'838GC3HV$!J'KV6Y,B>9)P>L;2,'F!4P)WHGV
M3`'&38GH2<'M`DG!X!Y!B?--">A)B<6)P$TQQ4@#A"3X````1#'J38G=2(V,
M$:'KV6Y,B=I)P>T;2,'B!4P)ZHG22`'13(GB2<'L`DC!XAY!B<U,">)-B<1%
MB<!),=1$,>9-B>Q(C;0PH>O9;DR)Z$G![!M(P>`%3`G@B<!(`?!,B=Y(P>8>
M2<'K`DP#A"0``0``3`G>28G308G$23'SB=)(`Y0D"`$``$0QV4V)XTV-A`BA
MZ]EN3(GA2<'K&TC!X05,"=F)R4D!R$R)Z4G![0)(P>$>18G#3`GI28GUB?9)
M,<U(`[0D$`$``$0QZ$V)W4B-E`*AZ]EN3(G82<'M&TC!X`5,">B)P$@!PDR)
MX$G![`)(P>`>08G53`G@28G,B<E),<1%,>!-B>Q.C80&H>O9;DR)[DG![!M(
MP>8%3`GFB?9,`<9-B=A)P>L"2<'@'D&)]$T)V$@#C"08`0``28G#33'#B<!(
M`X0D(`$``$0QVDV)XTG!ZQM(C8P1H>O9;DR)XDC!X@5,"=J)TD@!T4R)ZDG!
M[0)(P>(>08G+3`GJ38G%18G`23'53`.$)"@!``!$,>Y-B=U(C;0PH>O9;DR)
MV$G![1M(P>`%3`GHB<!(`?!,B>9)P>P"2,'F'D&)Q4P)YDF)U(G223'T2`.4
M)#`!``!$,>%-B>Q-C80(H>O9;DR)Z4G![!M(P>$%3`GAB<E)`<A,B=E)P>L"
M2,'A'D6)Q$P)V4F)\XGV23'+1#'838GC2`.T)#@!``!(C90"H>O9;DR)X$G!
MZQM(P>`%3`G81(T<$$R)Z$G![0)(P>`>3`GH28G-B<E),<6)PD4QZ$V)W4Z-
MA`:AZ]EN3(G>2<'M&TC!Y@5,">Y,BZPD0`$``$:--`9-B>!)P>P"2<'@'DT)
MX$P)P$2)QDF)Q$B)T$@A\$TAW$D)Q+C<O!N/20'%3`'I38GU20',3(GQ2<'M
M&TC!X05,">E)B?5!`<Q,B=E)P>L"2,'A'DP)V4&)RTD)R$TA\$TAW4T)Z$R+
MK"1(`0``20'%3`'J38GE20'03(GB2<'M&TC!X@5,">I&C2P"3(GR2<'N`DC!
MXAY,"?)-B=Y!B=!("=%-(<9,(>%,"?%,B[0D4`$``$D!QDP!]DV)[D@!\4R)
M[DG![AM(P>8%3`GV1(TT#DR)YDG![`)(P>8>3`GF38G$B?%("?))(<Q,(>I,
M">),BZ0D6`$``$D!Q$T!XTV)]$P!VDV)\TG!XP5)P>P;30GC18TD$TV)ZTG!
M[0))P>,>30GK28G-1(G:3`G>22'53"'V3`GN3(NL)&`!``!)`<5-`>A-B>5,
M`<9-B>!)P>T;2<'@!4T)Z$6-+#!-B?!)P>X"2<'@'DT)\$F)UD2)QDT)PTDA
M]DTAXTT)\TR+M"1H`0``20'&3`'Q38GN20'+3(GI2<'N&TC!X05,"?%&C309
M3(GA2<'L`DC!X1Y,">%)B?1!B<M)"<A-(>A-(=Q-">!,BZ0D<`$``$D!Q$P!
MXDV)]$D!T$R)\DG![!M(P>(%3`GB1HTD`DR)ZDG![0)(P>(>3`GJ38G=08G0
M2`G132'%3"'Q3`GI3(NL)'@!``!)`<5,`>Y-B>5(`?%,B>9)P>T;2,'F!4P)
M[D2-+`Y,B?9)P>X"2,'F'DP)]DV)QHGQ2`GR22'.3"'B3`GR3(NT)(`!``!)
M`<9-`?--B>Y,`=I-B>M)P>,%2<'N&TT)\T6--!--B>-)P>P"2<'C'DT)XTF)
MS$2)VDP)WDDAU$PA[DP)YDR+I"2(`0``20'$30'@38GT3`'&38GP2<'L&TG!
MX`5-">!%C20P38GH2<'M`DG!X!Y-">A)B=5$B<9-"<-)(?5-(?--">M,BZPD
MD`$``$D!Q4P!Z4V)Y4D!RTR)X4G![1M(P>$%3`GI1HTL&4R)\4G![@)(P>$>
M3`GQ28GV20G(08G+32'>32'@30GP3(NT))@!``!)`<9,`?)-B>Y)`=!,B>I)
MP>X;2,'B!4P)\D:--`),B>))P>P"2,'B'DP)XDV)W$&)T$@)T4TAQ$PAZ4P)
MX4R+I"2@`0``20'$3`'F38GT2`'Q3(GV2<'L&TC!Y@5,">9$C20.3(GN2<'M
M`DC!YAY,">Y-B<6)\4@)\DDAS4PA\DP)ZDR+K"2H`0``20'%30'K38GE3`':
M38GC2<'M&TG!XP5-">M%C2P338GS2<'N`DG!XQY-"?-)B<Y$B=I,"=Y)(=9,
M(>9,"?9,B[0DL`$``$D!QDT!\$V)[DP!QDV)Z$G![AM)P>`%30GP18TT,$V)
MX$G![`))P>`>30G@28G41(G&30G#22'T32'K30GC3(ND)+@!``!)`<1,`>%-
MB?1)`<M,B?%)P>P;2,'A!4P)X4:-)!E,B>E)P>T"2,'A'DP)Z4F)]4&)RTD)
MR$TA\$TAW4T)Z$R+K"3``0``20'%3`'J38GE20'03(GB2<'M&TC!X@5,">I&
MC2P"3(GR2<'N`DC!XAY-B=A,"?)!B=9("=%-(?!,(>%,"<%,BX0DR`$``$D!
MP$P!QDV)Z$@!\4R)[DG!Z!M(P>8%3`G&1(T$#DR)YDG![`)(P>8>3(GQ3`GF
M08GT2`GR3"'A3"'J2`G*2(N,)-`!``!(`<%)`<M,B<%(`X0DV`$``$P!VDV)
MPTC!X05)P>L;3`G9B<E,`?!(`<I,B>E)P>T"2,'A'D&)TTP)Z4V)Y4&)ST@)
MSDTA_4PAQDP)[DV)W4@!\$R)WDG![1M(P>8%3`GNB?9(`?!,B<9)P>@"2,'F
M'D&)Q4D)\+[6P6+*3#'!,<I(BXPDX`$``$@!\4D!S$R)Z4P!XDV)[$C!X05)
MP>P;3`GAB<E(`<I,B=E(P>$>2<'K`D&)U$D)RTR)P4V)YDPQV4G![AM%B<`Q
MR$B+C"3H`0``2`'Q20'/2HT,.$R)X$C!X`5,"?")P$R--`%,B>A)P>T"2,'@
M'DR)V46)VTD)Q4B+A"3P`0``18GW3#'I,<I,B?E(`?!(P>D;3`'`2`'"3(GX
M2,'@!4@)R$B+C"3X`0``B<!(`<),B>!)P>P"2,'@'D@!\4&)T$P)X$P!V4V)
MZTDQPTV)Q$6)[44QWDG![!M.C1PQ3(G!2,'A!4P)X8G)20'+3(GY2<'O`DC!
MX1Y%B=Q)"<](BXPD``(``$@!\4P!Z4F)Q8G`33']1#'J3(TL$4R)XDR)X4C!
MZ1M(P>(%2`G*3(G!2<'H`HG22,'A'DD!U4B+E"0(`@``3`G!38GX18GN18G_
M23'(2`'R13'#2`'03(GR3HT$&$R)\$C!ZAM(P>`%2`G02(G*B<F)P$D!P$R)
MX$G![`)(P>`>18G#20G$2(N$)!`"``!,,>)!,=5,B=I(`?!,`?A)`<5,B=A(
MP>`%2,'J&T@)T$R)\DG![@*)P$C!XAY)`<5(BX0D&`(``$P)\D6)[T@!\$@!
MR$R)X46)Y$@QT4$QR$R)^4D!P$R)^$C!Z1M(P>`%2`G(B<!)`<!,B=A)P>L"
M2,'@'D6)QDD)PTB+A"0@`@``3(GQ2,'I&T@!\$P!X$F)U(G233'<13'E3HTD
M*$R)\$C!X`5("<A(BXPD*`(``(G`20'$3(GX2<'O`D@!\4C!X!Y%B>5,"?A(
M`<I,B=E(,<%%B=M!,<A,B>E)`=!,B>I(P>D;2,'B!4@)RHG220'03(GR2<'N
M`DC!XAY%B<=)"=9(BY0D,`(``$R)^4C!Z1M(`?),`=I)B<.)P$TQ\T4QW$Z-
M'"),B?I(P>(%2`G*3(GI2<'M`HG22,'A'DD!TTB+E"0X`@``3`GI18G<2`'R
M2`'03(GR18GV2#'*03'03(GB20'`3(G@2,'J&TC!X`5("=!(B<J)R8G`20'`
M3(GX2<'O`DC!X!Y%B<5)"<=(BX0D0`(``$@!\$PQ^DP!\$$QTTR)ZDD!PTR)
MZ$C!ZAM(P>`%2`G03(GB2<'L`HG`2,'B'DD!PTB+A"1(`@``3`GB18G>28G4
M2`'P2`'(3(GY18G_2#'1B=)!,<A*C0P`3(GP38GP2<'H&TC!X`5,"<")P$@!
MP4R)Z$G![0)(P>`>08G(20G%2(N$)%`"``!-,>Q%,>--B<1(`?!)P>P;3`'X
M20'#3(G`2,'@!4P)X(G`20'#3(GP2,'@'DG![@)%B=Q,"?!,B[0D6`(``$D!
M]DD!UDR)ZD6)[4@QPC'128T4#DR)X4V)YDG![AM(P>$%3`GQB<E(`<I,B<%)
MP>@"2,'A'D&)UDD)R$B+C"1@`@``2`'Q3`'I28G%B<!-,<5%,>M-B?5)`<M,
MB?%)P>T;2,'A!4P)Z8G)20'+3(GA2<'L`DC!X1Y%B=U)"<Q(BXPD:`(``$@!
M\4@!R$R)P46)P$PQX3'*2(T,$$R)Z$R)ZDC!ZAM(P>`%2`G03(GR2<'N`DC!
MXAZ)P$D)UDB+E"1P`@``2`'!B<A(`?),`<)-B>!-,?!%,<-)B<!,`=I)B<-)
MP>`%2<'K&TT)V$F)PTC!Z`))P>,>00'03(GJ20G#2(N$)'@"``!(P>(>2<'M
M`D$!VTD)U42)XDR)7Q!(`?!$`>U(`<),B?!(B6\83#'H,<%(C00*3(G"3(G!
M2,'B!4C!Z1M%`<A("<I,B4<(`=!!`<)$`W<@2(N$)(@"``!D2#,$)2@```!,
MB1=,B7<@=1)(@<28`@``6UU!7$%=05Y!7\/HXN/__V:005=!5D%505154TB#
M[`A(A?\/A+$```!,BSVJ>"``387_#X2A````#[8'A,!T!#P]=5Y%,>1)BQ](
MA=MT.4F)]4F)_DUCY$R)_0\?@`````!,B>),B?9(B=_HPN+__X7`=0="@#PC
M/71'2(/%"$B+70!(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\
M28/$`4$/M@0DA,!T!#P]=>]!*?SKC`\?@`````!,*?U*C5PC`4C!_0-!B6T`
MZ[1F#Q]$```QV^NJ#Q]``%532(G]2(/L&&1(BP0E*````$B)1"0(,<!(C5PD
M!&:0,<!(B=Y(B>_H`____TB%P'0V2&-4)`1(BP6Z=R``2(T$T$B+4`A(A=)(
MB1!TTF:02(/`"$B+4`A(A=)(B1!U\.N^9@\?1```2(M$)`AD2#,$)2@```!U
M!TB#Q!A;7</HC.+__V:09BX/'X0``````$%7059!54%455-(B?-(B?U(@^PH
M9$B+!"4H````2(E$)!@QP#'`@#X]#Y3`2`'#2(G?Z#GB__](C70D%$F)Q$B)
M[S'`Z%?^__](A<`/A`X!``!(B<=)B<7H$^+__TPYX`^#X@```$QC="042<'F
M`P^V10"$P`^$K0$``#P]#X2E`0``2(GHZPT/'X0``````(#Z/70+2(/``0^V
M$(32=?!(*>A(F$P#-;QV(`!*C7P@`NCZXO__2(7`28D&#X1[`0``2&-4)!1(
MBP6:=B``2(U-`4B+%-`/MD4`/#V(`G0FA,!U$.L@9BX/'X0``````#P]=!)(
M@\$!#[9!_TB#P@&$P(@"=>K&`CTQP`\?1```#[8,`XA,`@%(@\`!A,EU\#'`
M2(MT)!AD2#,T)2@````/A1$!``!(@\0H6UU!7$%=05Y!7\,/'P!(@\,!#[9#
M_TF#Q0&$P$&(1?]U[.O"9I!,BST!=B``28,_``^$OP```$R)^#'2ZPL/'X0`
M`````$2)ZDB#P`A$C6H!2(,X`'7OC7(#2&/V2,'F`XL%_X4@`(7`=5M(B??'
M!>Z%(``!````Z/GA__](A<`/A'T```!-8\5,B?Y(B<=.C33%`````$R)1"0(
M3(GRZ(+B__],BT0D"$B)P4B)!7MU(`!*QT3!"`````!$B6PD%.EO_O__3(G_
MZ#CB__](A<!(B<%(B053=2``="9-8\5.C33%`````.O)#Q]``#'`Z7;^__^0
MOA````!%,>WI7O___[C_____Z=O^___H-.#__P\?0`!!5T%6055!5%532('L
MN````&1(BP0E*````$B)A"2H````,<!(A?]T"(`_`$F)_G4O2(N$)*@```!D
M2#,$)2@````/A20!``!(@<2X````6UU!7$%=05Y!7\-F#Q]$``#H:]___TB%
MP$B)PW3$2(U$)!!(C2WL&P``3(TEY!L``$R-/>`;``!(B00D2(G?Z(WA__](
MA<`/A+0```!,C4@3N0(```!(B>],B<[SIG3<N0,```!,B<Y,B>?SIG3-3(GW
M3(E,)`CH5=___TR+3"0(28G%3(G/Z$7?__]!C7P%`DAC_^AXX/__3(M,)`A)
MB<5(B<=-B?!,B?E(Q\+_____O@$````QP.C4X?__2(L4)+\!````3(GNZ*/>
M__^#^/],B>]T$(M$)"@E`/```#T`0```=##H)M[__TR)[^C^W?__Z43___]F
M#Q^$``````!(B=_H6-___TR)]^BPWO__Z<S^___HEO[__^O.Z+_>__\/'T0`
M`&8N#Q^$``````!32(G[BSUF<R``Z,'?__](C9```@``2(G>OP$```#HW>#_
M_X7`=`DQP%O##Q]$``"+/3IS(`#HE=___XN`&`(``"4`\```/0!```!T'8L]
M'7,@`.AXW___BX`8`@``)0#P```]`*```'6]2(G?O@(```#H2>#__X7`#Y3`
M#[;`6\,/'T0``&8N#Q^$``````!!5D%528GV051528G\4TB-/4@:``"Z_P\`
M`$B![!`0``!(B>-(B=YD2(L$)2@```!(B80D"!```#'`Z$'=__^%P`^.B0``
M`(U0_T2++8]R(`!(8^J`/"P`=%9(8^A(B>J^+P```$B)W^ACWO__2(7`=$9$
MB>_HQM[__TB)Z4B)VDR)YDB)Q^C%W___2(N$)`@0``!D2#,$)2@```!U.TB!
MQ!`0``!;74%<05U!7L-FD(72=:D/'T``1(GOZ(#>__],B?),B>9(B<?HDMW_
M_^N[1(LM"7(@`.O?Z$+=__]FD$B#[`B+/?9Q(`#H4=[__TB+%8IQ(`!(C0U3
M&P``2(TU:!D``$B)QTB#Q`CI<-[__TB#[`B+/<9Q(`#H(=[__TB)Q^BY____
MBSVS<2``Z`[>__],C07(&@``2(T5$!0``$B--4$9``!%,<E(B<=(@\0(3(G!
MZ7?>__\/'X``````55-(@>PH(```9$B+!"4H````2(F$)!@@```QP$B)XTB-
MK"00$```Z!3<__],C0W5&```2(T-`QD``$&)P+H!$```O@$```!(B=\QP.@?
MW___N@`0``!(B>Y(B=_HO]O__X7`>%.->`%(B<-(8__H?=W__TB%P$B)P708
M2&/;2(GN2(G'2(G:Z#3=__](B<'&!!@`2(N4)!@@``!D2#,4)2@```!(B<AU
M$TB!Q"@@``!;7<,/'T0``#')Z]?H_]O__P\?1```9BX/'X0``````.DK____
MD&8N#Q^$``````!!5T%6055!5$F)]%532(G[2(T]4A@``$B!["@0``!D2(L$
M)2@```!(B80D&!```#'`2(UT)`SHQ??__[XO````2(G?2(G%Z+7;__](A<!T
M0$B-/1L8``!(B=XQP.C_^/__2(G82(N,)!@0``!D2#,,)2@````/A9H!``!(
M@<0H$```6UU!7$%=05Y!7\,/'P!(B=_H.-O__TB-->`7``!,B>=!B<7H5MW_
M_TB%P$F)QW2>08/%`4&`/P!,C60D$$R--;L7```/A.(````/'T``2(7M=!-,
MB?Y(B>_HT-O__X7`#X2B````3(G_Z.#:__^)PDB808!\!_\O=1</'T``@^H!
M2&/"08!\!_\O0<8$!P!T[40!ZH'Z_P\```^/+O___TB#[`A(C0U*&```38GQ
M4TV)^+H`$```O@$```!,B><QP.A(W?__BSU2;R``Z*W;__](C9```@``3(GF
MOP$```#H"=K__X7`6EEU'8L]+6\@`.B(V___BX`8`@``)0#P```]`(```'1>
M2(TU[A8``#'_Z&C<__](A<!)B<</A*S^__]!@#\`#X4B____2(7M=!U(C3U;
M%@``N0(```!(B>[SIG3$9BX/'X0``````$R-/3X6``"Z`0```.DR____#Q^`
M`````+X!````3(GGZ/O;__^%P'612(T]<A8``$R)YNA8]___3(GGZ&#<___I
M3_[__^C&V?__9@\?1```#[872(GXA-)T'F8/'T0``$B#QP&`^B\/MA=(#T3'
MA-)U[O/##Q]``//#9@\?1```2(7_#X3/````55-(@^P(#[8O0(3M="E(B?OH
M8=G__TB-5`/_2#G3<A#K.P\?1```2(/J`4@YTW0W@#HO=/+K'4B#Q`A(C3UZ
M%0``6UWISMO__V8/'T0``(`Z+W0X2(/J`4@YTW+R2#G3=2H/'T0``$"`_2]T
MRDB#Q`A(C3VP%0``6UWIF-O__P\?A```````@#HO=0E(@^H!2#G3<O)(*=I(
MC4("2#T`$```=SM(C3W\;2``2(/"`;D`$```2(G>Z%O:__](C07D;2``2(/$
M"%M=PP\?1```2(T]YA0``.D\V___#Q]``#'`Z^`/'T``4TB-/3L5``!(@^Q`
M9$B+!"4H````2(E$)#@QP`^W!:46``!(C5PD#/,/;P5X%@``#RE$)!!FB40D
M,#'`\P]O!706```/*40D(.A"]?__2(T]]Q0``#'`Z#3U__](C3WQ%```,<#H
M)O7__TB-/>P4```QP.@8]?__2(T]Y10``#'`Z`KU__](C3WG%```,<#H_/3_
M_TB-/8X4```QP.CN]/__2(T]UQ0``#'`Z.#T__](C3W3%```,<#HTO3__TB-
M/<\4```QP.C$]/__2(T]7Q0``#'`Z+;T__](C3V]%```,<!(B=[HU?/__TB%
MP'012(T]DQ0``$B)QC'`Z!_U__](C3VG%```,<!(B=[HKO/__TB%P'012(T]
MHQ0``$B)QC'`Z/CT__](C3V=%```,<!(B=[HA_/__TB%P'1"2(T]Y!,``$B)
MQC'`Z-'T__](C36B%```2(T]!Q0``#'`Z+ST__](BT0D.&1(,P0E*````'5B
M2(/$0%O#9@\?1```2(T]510``#'`2(G>Z"_S__](A<!U*DB-="0A2(T]2Q0`
M`+D*````\Z9UI$B-="0K2(T]R1,``#'`Z&+T___KCTB-/;D3``!(B<8QP.A/
M]/__Z7G____HQ=;__P\?1```2(/L&&1(BP0E*````$B)1"0(,<"+!59K(`"#
M^/]T&4B+?"0(9$@S/"4H````=4!(@\08PP\?0`!(C70D!$B-/5P3```QP.B5
M\O__2(G",<!(A=)T$@^V$H#Z,`^5P3'`A-(/E<`AR(D%`VL@`.NPZ$S6__]F
MD&8N#Q^$``````!(@^P(Z$?6__^)Q^CPU?__2(7`=`M(BP!(@\0(PP\?`#'`
MZ_1FD&8N#Q^$``````!!5%5(B?U32(T]7!,``$B#[!!D2(L$)2@```!(B40D
M"#'`2(UT)`3H!/+__TB%P$B)[G1\@#@`2(G#='1(B<?H;-C__TB%P'5U2(GO
MZ*_5__](B=])B<3HI-7__TF-?`0"Z-K6__](@^P(3(T-/A(``$B-#2\3``!3
M2,?"_____TB)QTF)Q$F)Z+X!````,<#H*]C__TB-/<X2``!,B>8QP.CJ\O__
M6%KK%&8/'T0``$B-/;,2```QP.C2\O__2(M$)`AD2#,$)2@```!U"4B#Q!!;
M74%<P^@TU?__#Q]``$%7059!54%428G]55-(C3VE$0``2('LB($``&1(BP0E
M*````$B)A"1X@0``,<!(C05Q$@``3(UD)"Q(QT0D0`````!(QX0DF```````
M``!(QT0D8`````!(B40D,$B-!0$1``!,B>9(B40D.$B-!=X1``!(B40D<$B-
M!<L1``!(B40D>$B-!2`2``!(B80D@````$B-!<T1``!(B80DB````$B-!0H2
M``!(B80DD````$B-!>(1``!(B40D4$B-!?,1``!(B40D6#'`Z(#P__](A<!T
M"8`X``^%4@(``#'`Z`O^__](A<!(B<,/A(\"``!(B=_H)]3__TB-?``!Z%W5
M__^`.P!)B<9T-TR-/:X1``!,B?4/'P!$#[8#2(GO,<!,B?E(Q\+_____O@$`
M``!(@\,!2(/%`NBCUO__@#L`==9(C5PD<$B-/0,1``#K$$B#PPA(BSM(A?\/
MA'@!```QP$R)YNCF[___2(7`2(G%=-Z`.`!TV4B)Q^@!]?__A<!TS4B)[^@U
MUO__2(7`28G'#X1!`0``9@\?A```````3(GZBPI(@\($C8'__O[^]]$AR"6`
M@("`=.F)P<'I$*F`@```#T3!2(U*`D@/1-&)P0#!3(GQ2(/:`TPI^HLQ2(/!
M!(V&__[^_O?6(?`E@("`@'3IB<;![A"I@(````]$QDB-<0)(#T3.B<9``,9(
M@]D#3"GQC9P*!`0``$ACVTB)W^@YU/__2(G%2(T%G1```$%63(T-EP\``$B-
M#800``!-B?A02,?"_____[X!````2(GO,<#HA=7__[[``0``2(GOZ!C2__^#
M^/]!6$%9=1+HVM'__T2+"$&#^1$/A=,(``"+/6=G(`#HPM/__TB-D``"``!(
MB>Z_`0```.C>U/__A<!!B<</A$,!``!)BTT`2(L]>&<@`$B-%?$0``!)B>B^
M`0```#'`,=OHX-3__^M^9@\?1```,>UF#Q]$``!(8\5(BUS$,$B%VW0[@#L`
M=#9(B=^#Q0'H@_/__X7`=-](B=_HM]3__TB%P$F)QP^%B_[__TACQ4B+7,0P
M2(7;=<MF#Q]$``!%,?_I</[__TB)QTB)!"3HY/O__TB+!"1(B<?H>-3__TB)
MPP\?1```2(N,)'B!``!D2#,,)2@```!(B=@/A>4(``!(@<2(@0``6UU!7$%=
M05Y!7\,/'T``2(T]$P\``#'M2(7_="9FD#'`3(GF@\4!Z+/M__](A<!T!8`X
M`'4I2&/%2(M\Q%!(A?]UW+\-````2(T=WPX``.B;TO__28G&Z3[]__\/'P!(
MB<?HZ-/__TB%P$B)PP^%#?W__^O!9BX/'X0``````(L]^F4@`.A5TO__BX`8
M`@``)0#P```]`$````^%G/[__XL]V64@`.@TTO__1(NP'`(``.@8T?__03G&
M#X5\_O__BSVY92``Z!32__^+@!@"```E_P$``#W``0``#X5;_O__2(G?Z`;2
M__](C3TT#@``2(G#3(GF,<#HXNS__TB%P`^$:0$``$B)Q^A!T___28M]`$B)
MQNC%]/__2(7`28G$#X1)`0``3(GGZ('0__^#^`-^/$ACT$B-/24.``"Y!0``
M`$F-=!3\\Z9U)(/X!`^$"P8``(/H!$B808!\!/\O#X3Z!0``9BX/'X0`````
M`#'`Z(GY__^%P'45,?9,B>?H"]+__X7`08G&#X7P````2(TU@0T``$B-/0(-
M``!,C27\#0``,<!,C2VS#```Z(WM___HB,___T%43(T-H`P``%!(C0VS#0``
M2,?"_____TF)Z+X!````2(G?,<#HCM+__UA:ZTUF+@\?A```````Z.O.__^#
M.!%U2^A!S___08/'`4B#[`A(C0U\#0``051!5TV)Z5!)B>A(Q\+_____O@$`
M``!(B=\QP.A!TO__2(/$(+[``0``2(G?Z-#.__^#^/]TJTB)[^B#SO__2(T]
M]0L``$B)WC'`Z.+L__](B=_H2OG__^EU_?__#Q]$``!-BV4`Z:[^__\/'X``
M````N@(```!(Q\;N____B<?HG='__TB-A"1P`0``N@8```!$B?=(B<9(B00D
MZ-'/__^`O"1P`0```'4.@+PD<0$``$,/A(D%```QTC'V1(GWZ%W1__^XB:O-
M[TR-K"2@````2,>$)*`````!(T5G2(F$)*@```!(+8O.$E=(QX0DN````'94
M,A!(B80DL````$@%\@08*TC'A"3(`````````$B)A"3`````28U%.$C'A"30
M`````````,>$)!@!````````2(E$)`@/'X0``````$B+-"2Z`(```$2)]^@?
MS___A<!)B<1!B<`/CG$!``!(B[PDR````$ECQ$B+E"30````C33'2#G^2(FT
M),@```!(@](`2,'H'4@!T$B)A"30````2&.$)!@!``"%P`^$'0$``$B+3"0(
M0;A`````2(LT)$$IP$4YQ$4/3L1(C3P!26/028G72(E4)!#HX,[__XN$)!@!
M``!$`?B#^$")A"08`0``#X56____18G@3(GO12GX3(M\)!!,`SPD1(E$)!SH
MNM/__T2+1"0<#Q]$``!!@_@_?GE!C4#`B40D','H!D&)Q(E$)!!)@\0!2<'D
M!DT!_`\?1```\T$/;P=,B>])@\=`#Q&$)-@```#S00]O1]`/$80DZ````/-!
M#V]'X`\1A"3X````\T$/;T?P#Q&$)`@!``#H1=/__TTY_'6XBT0D$$2+1"0<
MP>`&02G`2(M\)`A)8]"Y2````$R)_D2)1"00Z/?-__]$BT0D$$2)A"08`0``
MZ87^__\/'T0``$R+/"3I1____P\?@`````!$B??H2,W__TR+I"3(````3(NT
M)-````!,B>!(P>@#@^`_C5`!2)C&A`38````@(/Z.`^/@P(``+@X````,?8I
MT$ACTH/X"$F-5!4X#X/<`@``J`0/A88#``"%P'0+J`+&`@`/A8H#``!,B?!,
MB>]$B+0D$P$``$C!Z!A$B*0D%P$``$R-K"1``0``B(0D$`$``$R)\$C!Z!"(
MA"01`0``3(GP3(TUQ@D``$C!Z`B(A"02`0``3(G@2,'H&(B$)!0!``!,B>!(
MP>@0B(0D%0$``$R)X$4QY$C!Z`B(A"06`0``Z`G2__](BX0DH````$B)PHB$
M)",!``!(P>H81`^VPHB4)"`!``!(B<)(P>H0B)0D(0$``$B)PDB+A"2H````
M2,'J"(B4)"(!``!(B<*(A"0G`0``2,'J&(B4)"0!``!(B<)(P>H0B)0D)0$`
M`$B)PDB+A"2P````2,'J"(B4)"8!``!(B<*(A"0K`0``2,'J&(B4)"@!``!(
MB<)(P>H0B)0D*0$``$B)PDB+A"2X````2,'J"(B4)"H!``!(B<*(A"0O`0``
M2,'J&(B4)"P!``!(B<)(P>H0B)0D+0$``$B)PDB+A"3`````2,'J"(B4)"X!
M``!(B<*(A"0S`0``2,'J&(B4)#`!``!(B<)(P>H0B)0D,0$``$B)PDC!Z@B(
ME"0R`0``Z0P````/'P!&#[:$)"`!``!+C7QE`#'`3(GQ2,?"_____[X!````
M28/$`>A8S?__28/\%'722(T%?`@``,:$)&@!````4$%52(T--@@``$R-#2,'
M``"^`0```$F)Z$C'PO____](B=\QP.@9S?__65[IY_K__V:038MM"$V%[0^$
M`_K__TR)[^@[RO__2(/X`P^&\?G__TF-=`7\2(T]W0<``+D%````\Z9-#T3E
MZ=7Y__^X0````$ACRBG028U,#3AT#S'2B=:#P@$YPL8$,0!R\TR)[^@-T/__
M9@_OP`\1A"38````2<=%:`````!!#Q%%2$$/$458Z6/]__])BTT`2(L]SUX@
M`$B-%0@(``!)B>B^`0```#'`,=OH-\S__^G2]___B<%(QP(`````2,=$"O@`
M````2(U*"$B#X?A(*<H!T(/@^(/X"`^"$/W__X/@^#'2B=>#P@@YPDB)-#ER
M\^GY_/__@+PD<@$``$$/A6GZ__^`O"1S`0``0P^%6_K__X"\)'0!``!(#X5-
M^O__@+PD=0$``$4/A3_Z__^Z`@```$C'QL;___]$B??HE,O__TR+/"2Z*0``
M`$2)]TR)_NC0R?__2(T%Z@8``%!!5^EQ_O__D,<"`````,=$`OP`````Z7;\
M__\Q_V:)?`+^Z6K\___HW,C__V:09BX/'X0``````$%7059!54%455-(@^P8
MBSU\72``9$B+!"4H````2(E$)`@QP$R-;"0$Z,+)__^+/5Q=(`!(B</HM,G_
M_P^VD[@```!(C3U*!0``3(GNB)"Y````,<#HEN3__TB%P'0)@#@Q#X0(`P``
M,<#HP>___XL]&UT@`.AVR?__2(TU*@8``+D+````N@$```!(B<?H'<G__TB%
MP`^$Q````(,]76T@``%(BT`01(LUXEP@`$R+8"@/CJ\````Q[;L!````ZSH/
M'X``````28MW$$B+!25M(`!(8]-(BSS0Z,'(__^%P(L5&6T@``^%"`(``(/#
M`8/%`3G3#XWZ`0``1(GWZ.W(__\QR4ACU4R)YDB)Q^B]R?__2(7`#X3,`0``
M3(LX1(LU:EP@`$&+1PPE``0@`#T`!```=))$B??HLLC__TR)_KD"````,=)(
MB<?HT,?__T2+-3E<(`!(B<;I;?___Y!$BS4I7"``1(GWZ('(__](C34Z!0``
MN0,```"Z`0```$B)Q^@HR/__2(7`2(G#=#5(BT`0BSWV6R``2(LHZ$[(__](
MC14)!0``2(G'2(GNZ%S'__](BT,02(L8]D,.0`^%ZP$``(L]Q5L@`.@@R/__
M2(TU^00``+D#````N@$```!(B<?HQ\?__TB%P$B)PW0]2(T]:@,``#'`3(GN
MZ.[B__](A<!(B<4/A'(!``!(BT,0BSUX6R``2(L8Z-#'__](B>I(B<=(B=[H
MXL;__XL]7%L@`.BWQ___2(TU=P0``+H!````2(G'Z,/'__^+/3U;(`!(B</H
ME<?__TB-%6H$``!(B=Y(B<?HH\;__XL]'5L@`.AXQ___2(T]V@(``,:`N0``
M``!,B>XQP.A@XO__2(7`2(G#2(D%:VL@``^$G0```+[``0``2(G?Z'#%__^-
M4`&#^@%V"8/X$0^%#P$``$B+1"0(9$@S!"4H````#X7V````2(/$&%M=05Q!
M74%>05_##Q]``(L5$FL@`$2+-9M:(`"-0O\YZ`^%9_[__X/Z`0^.7O[__[L!
M````9I!$B?>#PP'HU<;__TR)YDB)Q^@:Q?__.1W4:B``1(LU75H@`'_;Z2W^
M__]F#Q]$``!(BSVQ:B``Z%3P__](A<!(B<-(B06O:B``#X5$____2(T]0@0`
M`#'`Z+/&__\/'P"`>`$`#X3U_/__Z>G\__^02(L%<6H@`(L]`UH@`$B+*$B+
M0Q!(BQCH5,;__TB)[DB)W^@)Y___Z8+^__\/'T``BSW:62``Z#7&__](B=Y(
MB<?HBL;__^GZ_?__Z`#%__^)P4B+!1]J(`!(C3WP`P``2(G:2(LP,<#H,\;_
M_P\?`%532(G]2(/L".A"Z___#[802(G#A-)T&@\?A```````2(/``8#Z+P^V
M$$@/1-B$TG7N,<#HY^W__TB%[70=A<!T&8!]``!T$TB-/2\"``"Y!````$B)
MWO.F=`=(@\0(6UW#2(/$"$B)[UM=Z4#D__](C04162``2(7`=`Q(BPCI[,3_
M_P\?0``QR>GAQ/__D$%7059!B?]!54%43(TE;E0@`%5(C2UN5"``4TF)]DF)
MU4PIY4B#[`A(P?T#Z/_"__](A>UT(#';#Q^$``````!,B>I,B?9$B?]!_Q3<
M2(/#`4@YW77J2(/$"%M=05Q!74%>05_#D&8N#Q^$``````#SPP``2(/L"$B#
MQ`C#`````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?
M4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P
M,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E
M<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`%!!4CHZ
M4&%C:V5R.CI615)324].`#$N,#0P`"UE`"TM`%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@``````````!P97)L>'-I+F,`````````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U
M;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T
M:6]N*0H```````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N
M("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D
M=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D
M=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD
M('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA
M;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN
M:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#
M;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R
M;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D
M871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P
M96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D[
M"FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T
M(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D
M<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@
M,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*
M;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR
M96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@
M/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I
M.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O
M9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE
M<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@
M+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O
M9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L
M(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L
M:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U
M;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN
M86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<
M9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT
M*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX
M?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT
M(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN
M86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL
M96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\
M7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@
M)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@
M,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*
M?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL
M96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R![
M"FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT
M('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@
M;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA
M;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS
M92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C
M?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D
M9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@
M:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@
M("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@
M<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q
M("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU
M;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD
M;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I
M=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]
M"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@
M97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@
M0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O
M<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D[
M"F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G
M(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@
M/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<
M-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R
M(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N
M;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,
M62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D
M871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]
M('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`]
M(&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?
M7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?
M(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@
M*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N
M9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@
M=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK
M(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E
M24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*
M;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@
M*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]
M("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:
M+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I
M9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R
M968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R
M:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE
M(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K
M:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q
M*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N
M=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L
M("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E
M*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I
M"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA
M<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET
M=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT
M*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#
M,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]
M"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H
M95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$
M:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M"B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92![
M"FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D
M92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD
M8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64[
M"GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD
M9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U
M;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E
M<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*
M<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B
M)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B
M.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD
M<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D[
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E
M="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM
M96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO
M*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D
M97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]
M+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]
M/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP
M<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A
M="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE
M>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D
M97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S
M($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M
M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T
M95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N
M86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE
M.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D
M<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E
M7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR
M97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI
M;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D
M9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@
M/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@
M?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S
M:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA
M;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E
M;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X
M+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I
M9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[
M4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@
M=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@
M)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H
M;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[
M7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@
M05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ
M=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD
M7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI
M('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D
M14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D
M<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,
M14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*
M?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*
M<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]
M"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@
M9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R
M8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E
M;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR
M97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!
M4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P
M96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D
M:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE
M.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*
M?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$[
M"E]?14Y$7U\*```````!&P,[[````!P```"`@___.`$``$"'__]@`0``4(?_
M_T0&``"`B?__"`$``)"*__]X`0``H*#__\@!``!PH?__%`(```"B__]``@``
M4*3__XP"``#0I?__V`(``&"F___X`@``0*?__SP#``!PI___5`,``,"G__]L
M`P``D*C__Y@#``"@J/__K`,``,"J__\,!```\*K__R`$``#@J___<`0``,"M
M__^4!```0*[__[`$``!PKO__S`0``%"O__\,!0``L+O__\0%``"@O___$`8`
M`!#`__]P!@``,,#__X@&``"@P/__T`8````````4``````````%Z4@`!>!`!
M&PP'")`!!Q`4````'````'"(__\K```````````````4``````````%Z4@`!
M>!`!&PP'")`!```D````'````$""___``P````X01@X82@\+=PB``#\:.RHS
M)"(`````%````$0```#8A?__"```````````````3````%P````0B?__#A8`
M``!"#A"/`D(.&(X#1@X@C01"#BB,!40.,(8&00XX@P='#M`%`^85"@XX00XP
M00XH0@X@0@X80@X00@X(00L```!(````K````-">___,`````$(.$(\"0@X8
MC@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X0
M0@X(20L`*````/@```!4G___A`````!!#A"&`D$.&(,#1PXP`G,*#AA!#A!!
M#@A!"P!(````)`$``+B?__],`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XP
MA@9!#CB#!TH.8`,F`0H..$$.,$$.*$(.($(.&$(.$$(."$0+2````'`!``"\
MH?__<0$```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#O`!?@H.
M.$$.,$$.*$(.($(.&$(.$$(."$<+`!P```"\`0``\*+__X$`````00X0@P)I
M"@X(1@L"4`X(0````-P!``!@H___W@````!"#A".`D(.&(T#10X@C`1!#BB&
M!40.,(,&4P[`(`*$"@XP00XH00X@0@X80@X00@X(0PL4````(`(``/RC__\P
M`````$0.$&<."``4````.`(``!2D__])`````$0.$'T."``H````4`(``$RD
M___!`````$$.$(8"00X8@P-'#L!``J<*#AA!#A!!#@A&"Q````!\`@``\*3_
M_P4`````````7````)`"``#LI/__&@(```!"#A"/`D(.&(X#0@X@C01"#BB,
M!40.,(8&00XX@P=1#N`@`F0*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"P*6#N@@
M2P[P('D.Z"!!#N`@````$````/`"``"LIO__*@````````!,````!`,``,BF
M___L`````$H.$(8"00X8@P-$#B!U"@X82,,.$$'&#@A+"V(*#AA(PPX00<8.
M"$T+`D`.&$$.$$$."$;#QE`.((,#A@(``"````!4`P``:*?__]L!````00X0
M@P)+#E`#;`$*#A!!#@A'"Q@```!X`P``)*G__W0`````1`X@;PH."$4+```8
M````E`,``(BI__\D`````$0.$%@*#@A$"P``/````+`#``"<J?__W`````!"
M#A",`D$.&(8#1`X@@P1+#C`"6`XX3PY`;@XX00XP:@H.($$.&$$.$$(."$$+
M`+0```#P`P``/*K__U0,````0@X0CP)"#AB.`T(.((T$0@XHC`5$#C"&!D$.
M.(,'3@[`@P(#&`(.R(,"4@[0@P)H#LB#`D(.P(,"`P(!"@XX00XP00XH0@X@
M0@X80@X00@X(10L#J@$.R(,"2`[0@P)A#LB#`D$.P(,"8P[(@P))#M"#`D(.
MV(,"1`[@@P)=#L"#`@/[!`[(@P)"#M"#`F@.R(,"00[`@P(#7P$*#LB#`D(.
MT(,"1@M(````J`0``.2U___M`P```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XP
MA@9!#CB#!T0.4`/+`@H..$$.,$$.*$(.($(.&$(.$$(."$4+,````/0$``"(
MN?__<`````!!#A"&`D$.&(,#1PX@`E8*#AA!#A!!#@A!"T0.&$0.$$$.""@`
M```H!0``!('__RT"````00X0A@)!#AB#`T0.4`.]`0H.&$$.$$$."$$+%```
M`%0%``"8N?__'P``````````````1````&P%``"@N?__90````!"#A"/`D(.
M&(X#10X@C01"#BB,!4@.,(8&2`XX@P=-#D!R#CA!#C!!#BA"#B!"#AA"#A!"
M#@@`$````+0%``#(N?__`@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M8"$````````@(0````````````````````````````````````````$`````
M`````0`````````!`````````,L!`````````0`````````:`@````````P`
M````````0!H````````-`````````(17````````&0````````"0JR``````
M`!L`````````"``````````:`````````)BK(```````'``````````(````
M`````/7^_V\`````F`(````````%``````````@-````````!@````````"0
M`P````````H`````````R00````````+`````````!@`````````%0``````
M``````````````,`````````R*T@```````"`````````(@%````````%```
M```````'`````````!<`````````N!0````````'`````````"`3````````
M"`````````"8`0````````D`````````&``````````>``````````@`````
M````^___;P`````!```(`````/[__V\`````H!(```````#___]O``````(`
M````````\/__;P````#2$0```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````+BK(```````````````````
M`````````'8:````````AAH```````"6&@```````*8:````````MAH`````
M``#&&@```````-8:````````YAH```````#V&@````````8;````````%AL`
M```````F&P```````#8;````````1AL```````!6&P```````&8;````````
M=AL```````"&&P```````)8;````````IAL```````"V&P```````,8;````
M````UAL```````#F&P```````/8;````````!AP````````6'````````"8<
M````````-AP```````!&'````````%8<````````9AP```````!V'```````
M`(8<````````EAP```````"F'````````+8<````````QAP```````#6'```
M`````.8<````````]AP````````&'0```````!8=````````)AT````````V
M'0```````$8=````````5AT```````!F'0```````'8=````````AAT`````
M``"6'0```````*8=````````MAT```````#&'0```````-8=````````YAT`
M``````#V'0````````8>````````%AX`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P````"H6@```````$=#
M0SH@*%5B=6YT=2`W+C(N,"TQ,G5B=6YT=3$I(#<N,BXP`$=#0SH@*%5B=6YT
M=2`V+C0N,"TX=6)U;G1U,2D@-BXT+C`@,C`Q-S$P,3```"YS:'-T<G1A8@`N
M:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO
M;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`
M+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A
M<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR96PN<F\`+F1Y;F%M:6,`+F1A=&$`
M+F)S<P`N8V]M;65N=```````````````````````````````````````````
M```````````````````````````````````````````````````+`````0``
M``(`````````.`(````````X`@```````!P````````````````````!````
M````````````````$P````<````"`````````%0"````````5`(````````@
M````````````````````!````````````````````"$````'`````@``````
M``!T`@```````'0"````````)`````````````````````0`````````````
M```````T````]O__;P(`````````F`(```````"8`@```````/@`````````
M!0`````````(````````````````````/@````L````"`````````)`#````
M````D`,```````!X"0````````8````!````"``````````8`````````$8`
M```#`````@`````````(#0````````@-````````R00`````````````````
M``$```````````````````!.````____;P(`````````TA$```````#2$0``
M`````,H`````````!0`````````"``````````(`````````6P```/[__V\"
M`````````*`2````````H!(```````"```````````8````"````"```````
M`````````````&H````$`````@`````````@$P```````"`3````````F`$`
M```````%``````````@`````````&`````````!T````!````$(`````````
MN!0```````"X%````````(@%````````!0```!<````(`````````!@`````
M````?@````$````&`````````$`:````````0!H````````7````````````
M````````!````````````````````'D````!````!@````````!@&@``````
M`&`:````````P`,``````````````````!``````````$`````````"$````
M`0````8`````````(!X````````@'@````````@````````````````````(
M``````````@`````````C0````$````&`````````#`>````````,!X`````
M``!2.0``````````````````$````````````````````),````!````!@``
M``````"$5P```````(17````````"0````````````````````0`````````
M``````````"9`````0````(`````````D%<```````"05P```````%`_````
M```````````````(````````````````````H0````$````"`````````."6
M````````X)8```````#L````````````````````!```````````````````
M`*\````!`````@````````#0EP```````-"7````````^`4`````````````
M``````@```````````````````"Y````#@````,`````````D*L@``````"0
MJP````````@````````````````````(``````````@`````````Q0````\`
M```#`````````)BK(```````F*L````````(````````````````````"```
M```````(`````````-$````!`````P````````"@JR```````*"K````````
M$P```````````````````!````````````````````#>````!@````,`````
M````N*L@``````"XJP```````!`"````````!@`````````(`````````!``
M````````B`````$````#`````````,BM(```````R*T````````P`@``````
M````````````"``````````(`````````.<````!`````P``````````L"``
M``````"P````````(`````````````````````@```````````````````#M
M````"`````,`````````(+`@```````@L````````(@0````````````````
M```@````````````````````\@````$````P````````````````````(+``
M``````!0`````````````````````0`````````!``````````$````#````
M`````````````````````'"P````````^P````````````````````$`````
+````````````````
